{
    "$graph": [
        {
            "class": "Workflow",
            "label": "CODEX analysis pipeline using Cytokit",
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/cytokit_config"
                },
                {
                    "type": "Directory",
                    "id": "#main/cytokit_output"
                },
                {
                    "type": "File",
                    "id": "#main/slicing_pipeline_config"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#main/cytokit_config",
                            "id": "#main/background_subtraction/cytokit_config"
                        },
                        {
                            "source": "#main/cytokit_output",
                            "id": "#main/background_subtraction/cytokit_output"
                        },
                        {
                            "source": "#main/slicing_pipeline_config",
                            "id": "#main/background_subtraction/pipeline_config"
                        }
                    ],
                    "out": [
                        "#main/background_subtraction/bg_sub_tiles",
                        "#main/background_subtraction/bg_sub_config"
                    ],
                    "run": "#background_subtraction.cwl",
                    "id": "#main/background_subtraction"
                },
                {
                    "in": [
                        {
                            "source": "#main/background_subtraction/bg_sub_tiles",
                            "id": "#main/ome_tiff_creation/bg_sub_tiles"
                        },
                        {
                            "source": "#main/cytokit_config",
                            "id": "#main/ome_tiff_creation/cytokit_config"
                        },
                        {
                            "source": "#main/cytokit_output",
                            "id": "#main/ome_tiff_creation/cytokit_output"
                        }
                    ],
                    "out": [
                        "#main/ome_tiff_creation/ome_tiffs"
                    ],
                    "run": "#ome_tiff_creation.cwl",
                    "label": "Create OME-TIFF versions of Cytokit segmentation and extract results",
                    "id": "#main/ome_tiff_creation"
                },
                {
                    "in": [
                        {
                            "source": "#main/ome_tiff_creation/ome_tiffs",
                            "id": "#main/second_stitching/ometiff_dir"
                        },
                        {
                            "source": "#main/background_subtraction/bg_sub_config",
                            "id": "#main/second_stitching/pipeline_config"
                        }
                    ],
                    "out": [
                        "#main/second_stitching/stitched_images",
                        "#main/second_stitching/final_pipeline_config"
                    ],
                    "run": "#second_stitching.cwl",
                    "id": "#main/second_stitching"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "outputSource": "#main/second_stitching/final_pipeline_config",
                    "type": "File",
                    "label": "Pipeline config with all the modifications",
                    "id": "#main/final_pipeline_config"
                },
                {
                    "outputSource": "#main/second_stitching/stitched_images",
                    "type": "Directory",
                    "label": "Segmentation masks and expressions in OME-TIFF format",
                    "id": "#main/stitched_images"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "hubmap/codex-scripts:2.4.3",
                    "dockerOutputDirectory": "/output",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "python",
                "/opt/background_subtraction/run_background_subtraction.py"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--cytokit_config_path"
                    },
                    "id": "#background_subtraction.cwl/cytokit_config"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "--data_dir"
                    },
                    "id": "#background_subtraction.cwl/cytokit_output"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--pipeline_config_path"
                    },
                    "id": "#background_subtraction.cwl/pipeline_config"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "/output/config/pipelineConfig.json"
                    },
                    "id": "#background_subtraction.cwl/bg_sub_config"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "/output/background_subtraction"
                    },
                    "id": "#background_subtraction.cwl/bg_sub_tiles"
                }
            ],
            "id": "#background_subtraction.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Create OME-TIFF versions of Cytokit segmentation and extract results",
            "requirements": [
                {
                    "dockerPull": "hubmap/codex-scripts:2.4.3",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "python",
                "/opt/convert_to_ometiff.py"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#ome_tiff_creation.cwl/bg_sub_tiles"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#ome_tiff_creation.cwl/cytokit_config"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#ome_tiff_creation.cwl/cytokit_output"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "output"
                    },
                    "id": "#ome_tiff_creation.cwl/ome_tiffs"
                }
            ],
            "id": "#ome_tiff_creation.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "hubmap/codex-scripts:2.4.3",
                    "dockerOutputDirectory": "/output",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "python",
                "/opt/codex_stitching/secondary_stitcher/secondary_stitcher_runner.py"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "--ometiff_dir"
                    },
                    "id": "#second_stitching.cwl/ometiff_dir"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--pipeline_config_path"
                    },
                    "id": "#second_stitching.cwl/pipeline_config"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "/output/pipelineConfig.json"
                    },
                    "id": "#second_stitching.cwl/final_pipeline_config"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "/output/pipeline_output"
                    },
                    "id": "#second_stitching.cwl/stitched_images"
                }
            ],
            "id": "#second_stitching.cwl"
        }
    ],
    "cwlVersion": "v1.1"
}
